@@ -13,10 +13,14 @@
 
 #include <Akonadi/AgentManager>
 #include <Akonadi/Collection>
-#include <Akonadi/Item>
+#include <Akonadi/EntityTreeModel>
+
+#include <KCalUtils/ICalDrag>
 
 #include <KLocalizedString>
 
+#include <QMimeData>
+
 using namespace Akonadi;
 
 KCalendarCore::Incidence::Ptr CalendarUtils::incidence(const Akonadi::Item &item)
@@ -69,13 +73,13 @@ KCalendarCore::Journal::Ptr CalendarUtils::journal(const Akonadi::Item &item)
     return {};
 }
 
-QString CalendarUtils::displayName(Akonadi::ETMCalendar *calendar, const Akonadi::Collection &c)
+static QString displayNameImpl(const Akonadi::EntityTreeModel *model, const Akonadi::Collection &c)
 {
-    Akonadi::Collection fullCollection;
-    if (calendar && calendar->collection(c.id()).isValid()) {
-        fullCollection = calendar->collection(c.id());
-    } else {
-        fullCollection = c;
+    Akonadi::Collection fullCollection = c;
+    if (model) {
+        if (const auto col = Akonadi::EntityTreeModel::updatedCollection(model, c); col.isValid()) {
+            fullCollection = col;
+        }
     }
 
     QString cName = fullCollection.name();
@@ -86,10 +90,10 @@ QString CalendarUtils::displayName(Akonadi::ETMCalendar *calendar, const Akonadi
         QString typeStr = cName; // contents type: "Calendar", "Tasks", etc
         QString ownerStr; // folder owner: "fred", "ethel", etc
         QString nameStr; // folder name: "Public", "Test", etc
-        if (calendar) {
+        if (model) {
             Akonadi::Collection p = c.parentCollection();
             while (p != Akonadi::Collection::root()) {
-                Akonadi::Collection tCol = calendar->collection(p.id());
+                Akonadi::Collection tCol = Akonadi::EntityTreeModel::updatedCollection(model, Collection{p.id()});
                 const QString tName = tCol.name();
                 if (tName.startsWith(QLatin1String("shared.cal"), Qt::CaseInsensitive)) {
                     ownerStr = QStringLiteral("Shared");
@@ -150,9 +154,9 @@ QString CalendarUtils::displayName(Akonadi::ETMCalendar *calendar, const Akonadi
     // Google
     if (resourceName.contains(QLatin1String("google"))) {
         QString ownerStr; // folder owner: "user@gmail.com"
-        if (calendar) {
+        if (model) {
             Akonadi::Collection p = c.parentCollection();
-            ownerStr = calendar->collection(p.id()).displayName();
+            ownerStr = Akonadi::EntityTreeModel::updatedCollection(model, Collection{p.id()}).displayName();
         }
 
         const QString nameStr = c.displayName(); // folder name: can be anything
@@ -197,3 +201,53 @@ QString CalendarUtils::displayName(Akonadi::ETMCalendar *calendar, const Akonadi
         return i18nc("unknown resource", "Unknown");
     }
 }
+
+QString CalendarUtils::displayName(Akonadi::ETMCalendar *calendar, const Akonadi::Collection &c)
+{
+    return displayNameImpl(calendar ? calendar->entityTreeModel() : nullptr, c);
+}
+
+QString CalendarUtils::displayName(const Akonadi::EntityTreeModel *model, const Akonadi::Collection &c)
+{
+    return displayNameImpl(model, c);
+}
+
+QString CalendarUtils::displayName(const Akonadi::Collection &c)
+{
+    return displayNameImpl(nullptr, c);
+}
+
+QMimeData *CalendarUtils::createMimeData(const Akonadi::Item::List &items)
+{
+    if (items.isEmpty()) {
+        return nullptr;
+    }
+
+    KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+
+    QList<QUrl> urls;
+    int incidencesFound = 0;
+    for (const Akonadi::Item &item : items) {
+        const KCalendarCore::Incidence::Ptr incidence(CalendarUtils::incidence(item));
+        if (!incidence) {
+            continue;
+        }
+        ++incidencesFound;
+        urls.push_back(item.url());
+        KCalendarCore::Incidence::Ptr i(incidence->clone());
+        cal->addIncidence(i);
+    }
+
+    if (incidencesFound == 0) {
+        return nullptr;
+    }
+
+    auto mimeData = std::make_unique<QMimeData>();
+    mimeData->setUrls(urls);
+
+    if (KCalUtils::ICalDrag::populateMimeData(mimeData.get(), cal)) {
+        return mimeData.release();
+    } else {
+        return nullptr;
+    }
+}
