@@ -106,7 +106,7 @@ QString PublishDialog::addresses() const
     for (int i = 0; i < count; ++i) {
         QListWidgetItem *item = d->mUI.mListWidget->item(i);
         if (!item->text().isEmpty()) {
-            toList << item->text();
+            toList << KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(item->text()));
         }
     }
 
@@ -120,7 +120,7 @@ void PublishDialog::accept()
     if (addressOk != KEmailAddress::AddressOk) {
         KMessageBox::error(this,
                            i18n("Unable to publish the calendar incidence due to an "
-                                "invalid recipients string. %1",
+                                "invalid recipients string.\n%1",
                                 emailParseResultToString(addressOk)),
                            i18nc("@title:window", "Publishing Error"));
     } else {
